Introduction to Python and Microcontrollers

Class dht

Before each use of the object dht, add the statement import dht to the top of the Python file.

Adapted from Python_Tutorial.pdf — Chapter 24, Hygrothermograph DHT11