Introduction to Python and Microcontrollers

Class neopixel

Before each use of the neopixel module, add the statement import neopixel to the top of the Python file.

Adapted from Python_Tutorial.pdf — Chapter 6, LEDPixel