Before each use of the neopixel module, add the statement import neopixel to the top of the Python file.
NeoPixel(pin, n): Defines the output pin and number of LEDs of the neopixel module.
pin: Output pin.n: The number of LEDs.NeoPixel.write(): Writes data to the LEDs.Adapted from Python_Tutorial.pdf — Chapter 6, LEDPixel